@@ -8,6 +8,19 @@ from . import ImageDataset
 from .core import get_inception_feature
 
 
+def calc_and_save_stats(path, output, batch_size):
+    dataset = ImageDataset(path, exts=['png', 'jpg'])
+    loader = DataLoader(dataset, batch_size=batch_size, num_workers=4)
+    acts, = get_inception_feature(loader, dims=[2048], verbose=True)
+
+    mu = np.mean(acts, axis=0)
+    sigma = np.cov(acts, rowvar=False)
+
+    if os.path.dirname(output) != "":
+        os.makedirs(os.path.dirname(output), exist_ok=True)
+    np.savez_compressed(output, mu=mu, sigma=sigma)
+
+
 if __name__ == '__main__':
     parser = argparse.ArgumentParser("Pre-calculate statistics of images")
     parser.add_argument("--path", type=str, required=True,
@@ -18,13 +31,4 @@ if __name__ == '__main__':
                         help="batch size (default=50)")
     args = parser.parse_args()
 
-    dataset = ImageDataset(args.path, exts=['png', 'jpg'])
-    loader = DataLoader(dataset, batch_size=50, num_workers=4)
-    acts, = get_inception_feature(loader, dims=[2048], verbose=True)
-
-    mu = np.mean(acts, axis=0)
-    sigma = np.cov(acts, rowvar=False)
-
-    if os.path.dirname(args.output) != "":
-        os.makedirs(os.path.dirname(args.output), exist_ok=True)
-    np.savez_compressed(args.output, mu=mu, sigma=sigma)
+    calc_and_save_stats(args.path, args.output, args.batch_size)
